python-pure-cdb
===============

.. image:: https://travis-ci.com/bbayles/python-pure-cdb.svg?branch=master
    :target: https://travis-ci.com/bbayles/python-pure-cdb

.. image:: https://readthedocs.org/projects/python-pure-cdb/badge/?version=latest
    :target: https://python-pure-cdb.readthedocs.io/en/latest/?badge=latest

The `python-pure-cdb` package (`pure-cdb <https://pypi.org/project/pure-cdb/>`_ on PyPI)
is a Python library for working with D.J. Bernstein's "constant datbases."
It supports both Python 2.7 and Python 3.

In addition to being able to read and write the database files produced by
other `cdb` tools, `python-pure-cdb` can produce and consume "64-bit"
constant databases that don't have the usual 4 GiB restriction.

For more information on constant databases, see `djb's page <https://cr.yp.to/cdb.html>`_
and `Wikipedia <https://en.wikipedia.org/wiki/Cdb_(software)>`_.

The documentation for this package is available at
`https://python-pure-cdb.readthedocs.io <https://python-pure-cdb.readthedocs.io>`_.
